/*Copyright (C) 2019 Centro de Computacao Cientifica e Software Livre
Departamento de Informatica - Universidade Federal do Parana

This file is part of Plataforma Integrada MEC.

Plataforma Integrada MEC is free software: you can redistribute it and/or modify
it under the terms of the GNU Affero General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Plataforma Integrada MEC is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with Plataforma Integrada MEC.  If not, see <http://www.gnu.org/licenses/>.*/

import React, {Component} from 'react';
import axios from 'axios';
import {apiUrl} from '../env';
import './carousel.css';
import {Col,Row, Container, Hidden, Visible} from 'react-grid-system';
import ResourceCard from './ResourceCard';
import MaterialCard from './MaterialCard';
import CollectionCard from './CollectionCard';
import "react-responsive-carousel/lib/styles/carousel.min.css";
import { Carousel } from 'react-responsive-carousel';
import recursos from "../img/ilustra_recursos_digitais.png";
import materiais from "../img/ilustra_materiais.png";
import colecoes from "../img/ilustra_colecoes.png";
const areaStyle={
  paddingTop: "5px",
  fontSize: "16px",
  textAlign:"left",
  backgroundColor: "inherit",
  width: "700px",
  padding: "20px",
  minHeight: "150px"
}

class ReqResources extends Component{
  constructor(props){
    super(props);
    this.state = {
      resources: [],
    };
  }
  componentDidMount(){
    axios.get(`${apiUrl}/learning_objects?limit=12&sort=["published_at", "desc"]`)
    .then(res=> {
      this.setState({resources: res.data});
      console.log(res.data);
    });
  }
  render(){
      var row1 = this.state.resources.slice(0, 4);
      var row2 = this.state.resources.slice(4, 8);
      var row3 = this.state.resources.slice(8, 13);
    return(
      <Carousel showThumbs={false} infiniteLoop={true} showStatus={false}>
      <Row style={{paddingBottom: "5px"}}>
      {row1.map(card => <Col md={3} sm={6} key={card.id}>
        <ResourceCard name={card.name}
                      rating={card.score}
                      type={card.object_type}
                      description={card.description}
                      thumbnail={card.thumbnail}
                      author={card.author}
                      avatar={card.publisher.avatar}
                      /></Col>)}
      </Row>
      <Row>
      {row2.map(card => <Col md={3} sm={6} key={card.id}>
        <ResourceCard name={card.name}
                      rating={card.score}
                      type={card.object_type}
                      description={card.description}
                      thumbnail={card.thumbnail}
                      author={card.author}
                      avatar={card.publisher.avatar}
                      /></Col>)}
      </Row>
      <Row>
      {row3.map(card => <Col md={3} sm={6} key={card.id}>
        <ResourceCard name={card.name}
                      rating={card.score}
                      type={card.object_type}
                      description={card.description}
                      thumbnail={card.thumbnail}
                      author={card.author}
                      avatar={card.publisher.avatar}
                      /></Col>)}
      </Row>
    </Carousel>
    )
  }
}

class ReqCollections extends Component{
  constructor(props){
    super(props);
    this.state ={
      collections: [],
    };
  }
  componentDidMount(){
    axios.get(`${apiUrl}/collections?limit=12&sort=["updated_at", "desc"]`)
    .then(res=>{this.setState({collections: res.data});
    console.log(res.data);
  });
  }
  render(){
      var row1 = this.state.collections.slice(0, 4);
      var row2 = this.state.collections.slice(4, 8);
      var row3 = this.state.collections.slice(8, 13);
    return(
      <Carousel showThumbs={false} infiniteLoop={true} showStatus={false}>
      <Row style={{paddingBottom: "5px"}}>
      {row1.map(card => <Col md={3} sm={6} key={card.id}>
        <CollectionCard name={card.name}
                        rating={card.score}
                        author={card.owner.name}
                        description={card.description}
                        thumbnail={card.items_thumbnails}
                        avatar={card.owner.avatar}/></Col>)}
      </Row>
      <Row>
      {row2.map(card => <Col md={3} sm={6} key={card.id}>
        <CollectionCard name={card.name}
                        rating={card.score}
                        author={card.owner.name}
                        description={card.description}
                        thumbnail={card.items_thumbnails}
                        avatar={card.owner.avatar}/></Col>)}
      </Row>
      <Row>
      {row3.map(card => <Col md={3} sm={6} key={card.id}>
        <CollectionCard name={card.name}
                        rating={card.score}
                        author={card.owner.name}
                        description={card.description}
                        thumbnail={card.items_thumbnails}
                        avatar={card.owner.avatar}/></Col>)}
      </Row>
    </Carousel>
    )
  }
}

class SubPages extends Component{
  areaRender(){
    switch(this.props.banner){
    case "Recursos":
      return(
      <React.Fragment>
          <div style={{backgroundColor: "#ff7f00"}}>
              <Container style={areaStyle}>
                <img src={recursos}  alt="aba recursos" height="100" style={{float: "left"}}/>
                <p>Nesta área, você tem acesso a Recursos Educacionais Digitais, isto é,
                a vídeos, animações e a outros recursos destinados à educação. São Recursos
                de portais parceiros do MEC e de professores que, como você, atuam na
                Educação Básica!</p>
              </Container>
            </div>
            <Container style={{padding:"20px"}}>
              <p style={{paddingBottom:"5px", borderBottom: "1px solid #ff7f00", color: "#ff7f00"}}>
                Recursos mais recentes </p>
              <Hidden sm xs>
                <ReqResources/>
              </Hidden>
              <Visible sm xs>
                <ReqResources/>
              </Visible>
            </Container>
          </React.Fragment>
      );
    case "Materiais":
      return (
        <React.Fragment>
            <div style={{backgroundColor: "#e81f4f"}}>
                <Container style={areaStyle}>
                  <img src={materiais} alt="aba materiais" height="100" style={{float: "left"}}/>
                  <p>Nesta área, você acessa livremente materiais completos de formação,
                  como cursos já oferecidos pelo MEC e seus parceiros. São conteúdos
                  elaborados por equipes multidisciplinares e de autoria de pesquisadores
                  e educadores renomados nas áreas.</p>
                </Container>
              </div>
              <Container style={{padding:"20px"}}>
                <p style={{paddingBottom:"5px", borderBottom: "1px solid #e81f4f", color: "#e81f4f"}}>
                  Materiais mais recentes </p>

                <Carousel style={{padding: "20px"}}showThumbs={false} infiniteLoop={true} showStatus={false}>
                  <Row>
                  <Col md={3}>
                    <MaterialCard name="oioi" />
                  </Col>
                  <Col md={3}>
                    <MaterialCard name="oioi" />
                  </Col>
                  <Col md={3}>
                    <MaterialCard name="oioi" />
                  </Col>
                  <Col md={3}>
                    <MaterialCard name="oioi" />
                  </Col>
                  </Row>
                  </Carousel>
              </Container>
        </React.Fragment>
      );
    case "Colecoes":
      return (
        <React.Fragment>
            <div style={{backgroundColor: "#673ab7"}}>
              <Container style={areaStyle}>
                <img src={colecoes} alt="aba coleções" height="100" style={{float: "left"}}/>
                <p>Nesta área, você tem acesso às coleções criadas e organizadas
                pelos usuários da plataforma. É mais uma possibilidade de buscar
                recursos educacionais para sua aula!</p>
              </Container>
            </div>
            <Container style={{padding:"20px"}}>
              <p style={{paddingBottom:"5px", borderBottom: "1px solid #673ab7", color: "#673ab7"}}>
                Coleções mais recentes </p>
                <ReqCollections/>
            </Container>
        </React.Fragment>
          );
    default:
      return null
    }
  }

  render(){
    return(
      <div>
      {this.areaRender()}
      </div>
  );
}
}
export default SubPages;
